Enum ArgumentType
pub enum ArgumentType {
Int,
Uint,
Fixed,
Str(AllowNull),
Object(AllowNull),
NewId,
Array,
Fd,
}Available on crate feature
wayland and Linux only.Expand description
Enum of possible argument types as recognized by the wire
Variants
Int
An integer argument. Represented by a i32.
Uint
An unsigned integer argument. Represented by a u32.
Fixed
A signed fixed point number with 1/256 precision
Str(AllowNull)
A string. This is represented as a CString in a message.
Object(AllowNull)
Id of a wayland object
NewId
Id of a newly created wayland object
Array
Vec<u8>
Fd
A file descriptor argument. Represented by a RawFd.
Implementations
impl ArgumentType
impl ArgumentType
pub fn same_type(self, other: ArgumentType) -> bool
pub fn same_type(self, other: ArgumentType) -> bool
Returns true if the type of the argument is the same.